Installation
============

To run the OU Container Builder you need to install the following two requirements:

* `Python 3.7 (or higher) <https://www.python.org/downloads/>`_
* `Pipx <https://pipxproject.github.io/pipx/>`_

Then, to install the OU Container Builder run

.. sourcecode:: console

    $ pipx install "ou-container-builder>=2.0.0"
